from cepimose.types import LabDashboard
import unittest
import cepimose
import datetime
from nose.plugins.attrib import attr


class CepimoseTestCase(unittest.TestCase):
    def setUp(self):
        super().setUp()

    def tearDown(self):
        super().tearDown()

    def test_lab_start_timestamp(self):
        ts = cepimose.lab_start_timestamp()
        print("First NIJZ Covid-19 report:", ts)
        first_case = datetime.datetime(2020, 3, 4)
        today = datetime.datetime.now()

        self.assertEqual(first_case, ts)

    def test_lab_end_timestamp(self):
        ts = cepimose.lab_end_timestamp()
        print("Last update:", ts)
        day_delta = datetime.timedelta(days=3)
        today = datetime.datetime.now()
        diff = today - ts
        self.assertGreaterEqual(day_delta, diff)

    @attr("sledilnik")
    def test_lab_PCR_tests_performed(self):
        performed_PCR = cepimose.lab_PCR_tests_performed()
        self.assertGreaterEqual(performed_PCR, 0)
        self.assertLessEqual(performed_PCR, 15000)

    def test_lab_PCR_total_tests_performed(self):
        performed_PCR_total = cepimose.lab_PCR_total_tests_performed()
        self.assertGreaterEqual(performed_PCR_total, 1600000)
        self.assertLessEqual(performed_PCR_total, 1000000000)

    def test_lab_active_cases_estimated(self):
        active_cases_estimated = cepimose.lab_active_cases_estimated()
        self.assertGreaterEqual(active_cases_estimated, 0)
        self.assertLessEqual(active_cases_estimated, 2100000)

    def test_lab_confirmed_total_male(self):
        male_total = cepimose.lab_confirmed_total_male()
        self.assertGreaterEqual(male_total, 140000)
        self.assertLessEqual(male_total, 1000000000)

    def test_lab_total_vaccinated_first_dose(self):
        total_first_dose = cepimose.lab_total_vaccinated_first_dose()
        self.assertGreaterEqual(total_first_dose, 1180000)
        self.assertLessEqual(total_first_dose, 2100000)

    def test_lab_active_cases_100k(self):
        active_cases_100k = cepimose.lab_active_cases_100k()
        self.assertGreaterEqual(active_cases_100k, 0)
        self.assertLessEqual(active_cases_100k, 10000)
        self.assertIsInstance(active_cases_100k, float)

    def test_lab_cases_total_confirmed(self):
        cases_total = cepimose.lab_cases_total_confirmed()
        self.assertGreaterEqual(cases_total, 250000)

    def test_lab_HAT_total_tests_performed(self):
        performed_HAT = cepimose.lab_HAT_total_tests_performed()
        self.assertGreaterEqual(performed_HAT, 6500000)
        self.assertLessEqual(performed_HAT, 1000000000)

    @attr("sledilnik")
    def test_lab_cases_confirmed(self):
        cases_confirmed = cepimose.lab_cases_confirmed()
        self.assertGreaterEqual(cases_confirmed, 0)
        self.assertLessEqual(cases_confirmed, 10000)

    def test_lab_confirmed_total_female(self):
        female_total = cepimose.lab_confirmed_total_female()
        self.assertGreaterEqual(female_total, 160000)
        self.assertLessEqual(female_total, 1000000000)

    def test_lab_total_vaccinated_fully(self):
        fully_vaccinated = cepimose.lab_total_vaccinated_fully()
        self.assertGreaterEqual(fully_vaccinated, 1100000)
        self.assertLessEqual(fully_vaccinated, 2100000)

    def test_lab_cases_avg_7Days(self):
        cases_avg_7days = cepimose.lab_cases_avg_7Days()
        self.assertGreaterEqual(cases_avg_7days, 0)
        self.assertLessEqual(cases_avg_7days, 15000)

    @attr("sledilnik")
    def test_lab_HAT_tests_performed(self):
        performed_HAT = cepimose.lab_HAT_tests_performed()
        self.assertGreaterEqual(performed_HAT, 0)
        self.assertLessEqual(performed_HAT, 100000)

    def test_get_lab_dashboard(self):
        dashboard = cepimose.get_lab_dashboard()
        self.assertIsInstance(dashboard, LabDashboard)



from cepimose.enums import Manufacturer, Region
import datetime

from .types import (
    VaccinationByDayRow,
    VaccinationByAgeRow,
    VaccinationsDateRangeManufacturer,
    VaccineSupplyUsage,
    VaccinationByRegionRow,
    VaccinationByManufacturerRow,
    VaccinationDose,
    VaccinationMunShare,
    VaccinationAgeGroupByRegionOnDayDose,
    VaccinationAgeGroupByRegionOnDay,
)


def parse_date(raw):
    return datetime.datetime.utcfromtimestamp(float(raw) / 1000.0)


def _validate_response_data(data):
    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
            "odata.error"
        ]
        print(error)
        raise Exception("Something went wrong!")


def _parse_vaccinations_timestamp(data):
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    return parse_date(resp[0]["M0"])


def _parse_vaccinations_by_day(data) -> "list[VaccinationByDayRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data: "list[VaccinationByDayRow]" = []

    r_list = [None, 2, 4, 6, 8, 10, 12, 14]

    date = None
    people_vaccinated = None
    people_fully_vaccinated = None
    people_third_dose = None
    for element in resp:

        C = element["C"]
        R = element.get("R", None)
        date = parse_date(C[0])

        if R not in r_list:
            raise Exception(f"Unknown R: {R}, date: {date}, C: {C}!")

        if R == None:
            people_vaccinated = C[1]
            people_fully_vaccinated = C[2]
            people_third_dose = C[3]

        # reuse from previous iteration
        if R == 2:
            # reuse first dose
            people_vaccinated = parsed_data[-1].first_dose
            people_fully_vaccinated = C[1]
            people_third_dose = C[2]

        if R == 4:
            # reuse second dose
            people_vaccinated = C[1]
            people_fully_vaccinated = parsed_data[-1].second_dose
            people_third_dose = C[2]

        if R == 6:
            # reuse first and second dose
            people_vaccinated = parsed_data[-1].first_dose
            people_fully_vaccinated = parsed_data[-1].second_dose
            people_third_dose = C[1]

        if R == 8:
            # reuse third dose
            people_vaccinated = C[1]
            people_fully_vaccinated = C[2]
            people_third_dose = parsed_data[-1].third_dose

        if R == 10:
            # reuse first and third dose
            people_vaccinated = parsed_data[-1].first_dose
            people_fully_vaccinated = C[1]
            people_third_dose = parsed_data[-1].third_dose

        if R == 12:
            # reuse second and third dose
            people_vaccinated = C[1]
            people_fully_vaccinated = parsed_data[-1].second_dose
            people_third_dose = parsed_data[-1].third_dose

        if R == 14:
            # reuse all doses
            people_vaccinated = parsed_data[-1].first_dose
            people_fully_vaccinated = parsed_data[-1].second_dose
            people_third_dose = parsed_data[-1].third_dose

        parsed_data.append(
            VaccinationByDayRow(
                date=date,
                first_dose=people_vaccinated,
                second_dose=people_fully_vaccinated,
                third_dose=people_third_dose,
            )
        )

    return parsed_data


def _parse_vaccinations_by_age(data) -> "list[VaccinationByAgeRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        C = element["C"]
        age_group = str(C[0])
        share_second = float(C[1]) / 100.0
        share_first = float(C[2]) / 100.0
        count_first = int(C[3])
        count_second = int(C[4])

        parsed_data.append(
            VaccinationByAgeRow(
                age_group=age_group,
                count_first=count_first,
                count_second=count_second,
                share_first=share_first,
                share_second=share_second,
            )
        )

    return parsed_data


def _parse_vaccines_supplied_and_used(data) -> "list[VaccineSupplyUsage]":
    _validate_response_data

    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        print(element)
        date = parse_date(element["C"][0])

        if "Ø" in element:
            supplied = int(element["C"][1]) if len(element["C"]) > 1 else 0
            used = 0
        else:
            used = (
                int(element["C"][1]) if len(element["C"]) > 1 else parsed_data[-1].used
            )
            supplied = (
                int(element["C"][2])
                if len(element["C"]) > 2
                else parsed_data[-1].supplied
            )

        row = VaccineSupplyUsage(
            date=date,
            supplied=supplied,
            used=used,
        )
        parsed_data.append(row)

    return parsed_data


def _parse_vaccinations_by_region(data) -> "list[VaccinationByRegionRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        C = element["C"]
        region = str(C[0])
        count_first = int(C[3])
        count_second = int(C[4])
        share_first = float(C[1]) / 100.0
        share_second = float(C[2]) / 100.0

        parsed_data.append(
            VaccinationByRegionRow(
                region=region,
                count_first=count_first,
                count_second=count_second,
                share_first=share_first,
                share_second=share_second,
            )
        )

    return parsed_data


def _parse_vaccines_supplied_by_manufacturer(
    data,
) -> "list[VaccinationByManufacturerRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][1]["DM1"]
    manufacturers = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["ValueDicts"][
        "D0"
    ]
    parsed_data = []

    if len(manufacturers) > 4:
        print(manufacturers)
        raise Exception("New manufacturer!")

    def get_manufacturer(num):
        manu_keys = ["pfizer", "moderna", "az", "janssen"]
        if num > 3 or num == None:
            print(num)
            raise Exception("Missing manufacturer!")
        return manu_keys[num]

    r_list = [None, 1, 2, 4, 5, 6]

    date = None
    manufacturer = None
    value = None

    for element in resp:
        R = element["R"] if "R" in element else None
        C = element["C"]

        if R not in r_list:
            print(R, C, sep="\t")
            raise Exception("Unknown R value!")

        manu_row = VaccinationByManufacturerRow(
            date=None, pfizer=None, moderna=None, az=None, janssen=None
        )

        if R == None:
            # all data
            date = parse_date(C[0])
            manufacturer = get_manufacturer((C[1]))
            value = int(C[2])
            setattr(manu_row, "date", date)
            setattr(manu_row, manufacturer, value)

        if R == 1:
            # same date as previous
            manufacturer = get_manufacturer((C[0]))
            value = int(C[1])
            setattr(parsed_data[-1], manufacturer, value)

        if R == 2:
            # same manufacturer as previous
            date = parse_date(C[0])
            value = int(C[1])
            setattr(manu_row, "date", date)
            setattr(manu_row, manufacturer, value)

        if R == 4:
            # same value as previous, but different manufacturer
            date = parse_date(C[0])
            manufacturer = get_manufacturer((C[1]))
            setattr(manu_row, "date", date)
            setattr(
                manu_row, manufacturer, value
            )  # reuse value from previous iteration

        if R == 5:
            # same value, same date, but different manufacturer
            manufacturer = get_manufacturer((C[0]))
            setattr(
                parsed_data[-1], manufacturer, value
            )  # reuse value from previous iteration

        if R == 6:
            # same manufacturer and value as previous
            date = parse_date(C[0])
            setattr(manu_row, "date", date)
            setattr(manu_row, manufacturer, value)

        if R != 1 and R != 5:
            parsed_data.append(manu_row)
    return parsed_data


def _parse_vaccines_supplied_by_manufacturer_cum(
    data,
) -> "list[VaccinationByManufacturerRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for element in resp:
        elements = list(filter(lambda x: "M0" in x, element["X"]))

        date = parse_date(element["G0"])
        moderna = None
        pfizer = None
        az = None
        janssen = None

        for el in elements:
            if el.get("I", None) == 1:
                janssen = round(float(el["M0"]))
            elif el.get("I", None) == 2:
                moderna = round(float(el["M0"]))
            elif el.get("I", None) == 3:
                pfizer = round(float(el["M0"]))
            else:
                az = round(float(el["M0"]))

        parsed_data.append(
            VaccinationByManufacturerRow(
                date=date, pfizer=pfizer, moderna=moderna, az=az, janssen=janssen
            )
        )

    return parsed_data


def _parse_vaccinations_by_age_group(data) -> "list[VaccinationByDayRow]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    date = None
    people_vaccinated = None
    people_fully_vaccinated = None
    for element in resp:
        C = element["C"]
        if len(C) == 3:
            date = parse_date(C[0])
            people_vaccinated = C[1]
            people_fully_vaccinated = C[2]
        elif len(C) == 2:
            date = parse_date(C[0])
            R = element["R"]
            if R == 2:
                people_fully_vaccinated = C[1]
            else:
                people_vaccinated = C[1]
        elif len(C) == 1:
            # R == 6
            date = parse_date(C[0])
        else:
            raise Exception("Unknown item length!")

        parsed_data.append(
            VaccinationByDayRow(
                date=date,
                first_dose=people_vaccinated,
                second_dose=people_fully_vaccinated,
            )
        )

    return parsed_data


def _parse_vaccinations_by_region_by_day(data):
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    people_vaccinated = None
    people_fully_vaccinated = None
    for element in resp:
        C = element["C"]

        if len(C) == 3:
            date = parse_date(C[0])
            people_vaccinated = C[1]
            people_fully_vaccinated = C[2]
        elif len(C) == 2:
            date = parse_date(C[0])
            R = element["R"]
            if R == 2:
                people_fully_vaccinated = C[1]
            else:
                people_vaccinated = C[1]
        elif len(C) == 1:
            date = parse_date(C[0])
        else:
            raise Exception("Unknown item length!")

        parsed_data.append(
            VaccinationByDayRow(
                date=date,
                first_dose=people_vaccinated,
                second_dose=people_fully_vaccinated,
            )
        )

    return parsed_data


def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunShare]":
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    parsed_data = []

    for el in resp:
        C = el["C"]
        R = el.get("R", None)
        dose1 = None
        dose2 = None
        if len(C) == 4:
            name, share1, share2, population = C
            dose1 = round(population * float(share1))
            dose2 = round(population * float(share2))
        else:
            print(el)
            raise Exception(f"Unknown C length: {len(C)}")

        parsed_data.append(
            VaccinationMunShare(
                name=name,
                dose1=dose1,
                share1=float(share1),
                dose2=dose2,
                share2=float(share2),
                population=population,
            )
        )

    return parsed_data


def _parse_vaccinations_age_group_by_region_on_day(
    data,
) -> "list[VaccinationAgeGroupByRegionOnDay]":
    _validate_response_data(data)

    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]

    def parse_resp_data(region, item):
        if len(item) == 4:
            return VaccinationAgeGroupByRegionOnDayDose(
                region=region,
                total_share=float(item[0]),
                group_share=float(item[1]),
                total_count=item[2],
                group_count=item[3],
            )
        if len(item) == 3:
            return VaccinationAgeGroupByRegionOnDayDose(
                region=region,
                total_share=float(item[0]),
                group_share=float(item[1]),
                total_count=item[2],
            )
        if len(item) == 2:
            return VaccinationAgeGroupByRegionOnDayDose(
                region=region,
                total_share=float(item[0]),
                total_count=item[1],
            )
        raise Exception("Unknown item length!")

    parsed_data = []
    for el in resp:
        C = el["C"]
        region = C[0]
        if len(C) == 9:
            first_dose_data = [C[1], C[2], C[5], C[6]]
            second_dose_data = [C[3], C[4], C[7], C[8]]
            first_dose = parse_resp_data(region, first_dose_data)
            second_dose = parse_resp_data(region, second_dose_data)
            parsed_data.append(
                VaccinationAgeGroupByRegionOnDay(
                    region=region, dose1=first_dose, dose2=second_dose
                )
            )
        else:
            R = el.get("R", None)
            if R == 64:
                # ! not sure
                first_dose_data = [C[1], C[2], C[5], C[6]]
                second_dose_data = [C[3], C[4], C[7]]
                first_dose = parse_resp_data(region, first_dose_data)
                second_dose = parse_resp_data(region, second_dose_data)
                parsed_data.append(
                    VaccinationAgeGroupByRegionOnDay(
                        region=region, dose1=first_dose, dose2=second_dose
                    )
                )

    def is_missing(regions, value):
        try:
            regions.index(value)
            return False
        except ValueError:
            return True

    if len(Region) > len(parsed_data):
        regions = [item.region for item in parsed_data]
        missing_regions = [
            item.value for item in Region if is_missing(regions, item.value)
        ]
        for region in missing_regions:
            dose1 = VaccinationAgeGroupByRegionOnDayDose(region)
            dose2 = VaccinationAgeGroupByRegionOnDayDose(region)
            parsed_data.append(
                VaccinationAgeGroupByRegionOnDay(
                    region=region, dose1=dose1, dose2=dose2
                )
            )

    return parsed_data


def _parse_vaccinations_by_manufacturer_supplied_used(
    data,
) -> "list[VaccineSupplyUsage]":
    _validate_response_data(data)

    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]

    parsed_data = []
    item = None
    for el in resp:
        C = el["C"]
        date = parse_date(C[0])
        if len(C) == 2:
            item = VaccineSupplyUsage(date=date, supplied=round(float(C[1])), used=0)
            parsed_data.append(item)
        elif len(C) == 3:
            item = VaccineSupplyUsage(
                date=date, supplied=round(float(C[2])), used=round(float(C[1]))
            )
            parsed_data.append(item)
        else:
            print(el)
            raise Exception("Unknown [C] length")

    return parsed_data


def _parse_vaccinations_gender_by_date(data):
    _validate_response_data(data)

    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    return resp[0].get("M0", None)


# date range parsers
def _parse_vaccinations_date_range(data):
    _validate_response_data(data)

    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]

    parsed_data = []

    date = None
    people_vaccinated = None
    people_fully_vaccinated = None
    for element in resp:
        C = element["C"]
        if len(C) == 3:
            date = parse_date(C[0])
            people_vaccinated = C[1]
            people_fully_vaccinated = C[2]
        elif len(C) == 2:
            date = parse_date(C[0])
            R = element["R"]
            if R == 2:
                people_fully_vaccinated = C[1]
            else:
                people_vaccinated = C[1]
        elif len(C) == 1:
            # R == 6
            date = parse_date(C[0])
        else:
            raise Exception("Unknown item length!")

        parsed_data.append(
            VaccinationByDayRow(
                date=date,
                first_dose=people_vaccinated,
                second_dose=people_fully_vaccinated,
            )
        )

    return parsed_data


def _create_vaccinations_by_manufacturer_parser(manufacturer: Manufacturer):

    DAY_DELTA = datetime.timedelta(days=1)

    Manufacturer_First_Delivery_Date = {
        Manufacturer.PFIZER: datetime.datetime(2020, 12, 26),
        Manufacturer.MODERNA: datetime.datetime(2021, 1, 12),
        Manufacturer.AZ: datetime.datetime(2021, 2, 6),
        Manufacturer.JANSSEN: datetime.datetime(2021, 4, 14),
    }

    def _parse_vaccinations_by_manufacturer_used(data) -> "list[VaccinationDose]":
        # Here is possible to get data for, first, second, third and total.
        # We need total at the moment.
        _validate_response_data(data)
        resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]

        parsed_data: "list[VaccinationDose]" = []
        for element in resp:
            C = element.get("C")
            R = element.get(
                "R", None
            )  # maybe for later if we decide to parse for each dose
            Ø = element.get(
                "Ø", None
            )  # maybe for later if we decide to parse for each dose

            date = parse_date(C[0])
            total_used = C[-1]

            if R == 30:
                total_used = parsed_data[-1].dose

            # I have no idea what Ø is. I can speculate that is related to doses: first, second or third
            if R == 28 and Ø == None:
                total_used = parsed_data[-1].dose

            if R == 28 and Ø == 2:
                total_used = parsed_data[-1].dose

            parsed_data.append(VaccinationDose(date, total_used))

        return parsed_data

    return _parse_vaccinations_by_manufacturer_used


def _parse_vaccinations_date_range_manufacturers_used(data):
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]

    manu_dict = {
        "Astra Zeneca": "az",
        "Janssen": "janssen",
        "Moderna": "moderna",
        "Pfizer-BioNTech": "pfizer",
    }

    parsed_data = []
    for element in resp:
        C = element.get("C", None)
        manufacturer = C[0]
        result = VaccinationsDateRangeManufacturer(manu_dict[manufacturer])
        if len(C) == 3:
            result.dose1 = C[1]
            result.dose2 = C[2]
        if len(C) == 2:
            kind_of_zero = element.get("Ø", None)  # Do not mixup Ø with 0
            if kind_of_zero == 4:
                result.dose1 = C[1]
            elif kind_of_zero == None:
                result.dose2 = C[1]
            else:
                raise Exception(f'Unknown "Ø" value: {kind_of_zero}')

        parsed_data.append(result)
    return parsed_data


def _parse_single_data(data):
    _validate_response_data(data)
    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
    return resp[0]["M0"]



import datetime
from enum import unique
import unittest
from unittest.case import skip
import cepimose
from cepimose.enums import AgeGroup, Gender, Manufacturer, Region

_timestamp_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "DatumOsveževanja",
                                            }
                                        },
                                        "Function": 3,
                                    },
                                    "Name": "Min(eRCO_podatki.DatumOsvezevanja)",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T01:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {"DataVolume": 3, "Primary": {"Top": {}}},
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "CacheKey": '{"Commands":[{"SemanticQueryDataShapeCommand":{"Query":{"Version":2,"From":[{"Name":"e","Entity":"eRCO_​​podatki","Type":0},{"Name":"c","Entity":"Calendar","Type":0}],"Select":[{"Aggregation":{"Expression":{"Column":{"Expression":{"SourceRef":{"Source":"e"}},"Property":"DatumOsveževanja"}},"Function":3},"Name":"Min(eRCO_podatki.DatumOsvezevanja)"}],"Where":[{"Condition":{"Comparison":{"ComparisonKind":1,"Left":{"Column":{"Expression":{"SourceRef":{"Source":"c"}},"Property":"Date"}},"Right":{"DateSpan":{"Expression":{"Literal":{"Value":"datetime\'2020-12-26T01:00:00\'"}},"TimeUnit":5}}}}}]},"Binding":{"Primary":{"Groupings":[{"Projections":[0]}]},"DataReduction":{"DataVolume":3,"Primary":{"Top":{}}},"Version":1},"ExecutionMetricsKind":1}}]}',
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "da086fda6709e1327c0d",
                }
            ],
        },
    }
]

_by_age_group_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "c1", "Entity": "Calendar", "Type": 0},
                                {"Name": "c", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "x", "Entity": "xls_SURS_starost", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "c1"}},
                                        "Property": "Date",
                                    },
                                    "Name": "Calendar.Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Weight running total in Date",
                                    },
                                    "Name": "eRCO_podatki.Weight running total in Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Tekoča vsota za mero Precepljenost v polju Date",
                                    },
                                    "Name": "eRCO_podatki_ed.Tekoča vsota za mero Precepljenost v polju Date",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "x"}
                                                        },
                                                        "Property": "Starostni ​razred",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'90+'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Not": {
                                            "Expression": {
                                                "In": {
                                                    "Expressions": [
                                                        {
                                                            "Column": {
                                                                "Expression": {
                                                                    "SourceRef": {
                                                                        "Source": "c"
                                                                    }
                                                                },
                                                                "Property": "CepivoIme",
                                                            }
                                                        }
                                                    ],
                                                    "Values": [
                                                        [{"Literal": {"Value": "null"}}]
                                                    ],
                                                }
                                            }
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c1"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T01:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0, 1, 2]}]},
                            "DataReduction": {
                                "DataVolume": 4,
                                "Primary": {"BinnedLineSample": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "37907fcc1d650bd01406",
                }
            ],
        },
    }
]

_by_region_by_day_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "c1", "Entity": "Calendar", "Type": 0},
                                {"Name": "c", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "s", "Entity": "Sifrant_regija", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "c1"}},
                                        "Property": "Date",
                                    },
                                    "Name": "Calendar.Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Weight running total in Date",
                                    },
                                    "Name": "eRCO_podatki.Weight running total in Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Tekoča vsota za mero Precepljenost v polju Date",
                                    },
                                    "Name": "eRCO_podatki_ed.Tekoča vsota za mero Precepljenost v polju Date",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "s"}
                                                        },
                                                        "Property": "Regija",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Pomurska'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c1"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T01:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0, 1, 2]}]},
                            "DataReduction": {
                                "DataVolume": 4,
                                "Primary": {"BinnedLineSample": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "37907fcc1d650bd01406",
                }
            ],
        },
    }
]

_age_group_by_region_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "s1", "Entity": "Sifrant_regija", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "s1"}},
                                        "Property": "Regija",
                                    },
                                    "Name": "Sifrant_regija.Regija",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Delež_regija_1",
                                    },
                                    "Name": "eRCO_podatki.Delež_regija",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Delež_regija_precepljenost",
                                    },
                                    "Name": "eRCO_podatki_ed.Delež_regija_precepljenost",
                                },
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "Odmerek – kopija",
                                            }
                                        },
                                        "Function": 0,
                                    },
                                    "Name": "Sum(eRCO_​​podatki.Odmerek – kopija)",
                                },
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "Precepljenost",
                                            }
                                        },
                                        "Function": 0,
                                    },
                                    "Name": "Sum(eRCO_​​podatki.Precepljenost)",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "Not": {
                                            "Expression": {
                                                "In": {
                                                    "Expressions": [
                                                        {
                                                            "Column": {
                                                                "Expression": {
                                                                    "SourceRef": {
                                                                        "Source": "e"
                                                                    }
                                                                },
                                                                "Property": "CepivoIme",
                                                            }
                                                        }
                                                    ],
                                                    "Values": [
                                                        [{"Literal": {"Value": "null"}}]
                                                    ],
                                                }
                                            }
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Not": {
                                            "Expression": {
                                                "In": {
                                                    "Expressions": [
                                                        {
                                                            "Column": {
                                                                "Expression": {
                                                                    "SourceRef": {
                                                                        "Source": "s1"
                                                                    }
                                                                },
                                                                "Property": "Regija",
                                                            }
                                                        }
                                                    ],
                                                    "Values": [
                                                        [
                                                            {
                                                                "Literal": {
                                                                    "Value": "null"
                                                                }
                                                            }
                                                        ],
                                                        [
                                                            {
                                                                "Literal": {
                                                                    "Value": "'Celotna Slovenija'"
                                                                }
                                                            }
                                                        ],
                                                        [
                                                            {
                                                                "Literal": {
                                                                    "Value": "'TUJINA'"
                                                                }
                                                            }
                                                        ],
                                                    ],
                                                }
                                            }
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T01:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Measure": {
                                            "Expression": {
                                                "SourceRef": {"Source": "e"}
                                            },
                                            "Property": "Delež_regija_1",
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {
                                "Groupings": [{"Projections": [0, 1, 2, 3, 4]}]
                            },
                            "DataReduction": {
                                "DataVolume": 4,
                                "Primary": {"Window": {"Count": 1000}},
                            },
                            "SuppressedJoinPredicates": [3, 4],
                            "Version": 1,
                            "Highlights": [
                                {
                                    "Version": 2,
                                    "From": [
                                        {
                                            "Name": "x",
                                            "Entity": "xls_SURS_starost",
                                            "Type": 0,
                                        },
                                        {
                                            "Name": "e",
                                            "Entity": "eRCO_​​podatki",
                                            "Type": 0,
                                        },
                                    ],
                                    "Where": [
                                        {
                                            "Condition": {
                                                "In": {
                                                    "Expressions": [
                                                        {
                                                            "Column": {
                                                                "Expression": {
                                                                    "SourceRef": {
                                                                        "Source": "x"
                                                                    }
                                                                },
                                                                "Property": "Starostni ​razred",
                                                            }
                                                        }
                                                    ],
                                                    "Values": [
                                                        [
                                                            {
                                                                "Literal": {
                                                                    "Value": "'90+'"
                                                                }
                                                            }
                                                        ]
                                                    ],
                                                }
                                            }
                                        },
                                        {
                                            "Condition": {
                                                "Not": {
                                                    "Expression": {
                                                        "In": {
                                                            "Expressions": [
                                                                {
                                                                    "Column": {
                                                                        "Expression": {
                                                                            "SourceRef": {
                                                                                "Source": "e"
                                                                            }
                                                                        },
                                                                        "Property": "CepivoIme",
                                                                    }
                                                                }
                                                            ],
                                                            "Values": [
                                                                [
                                                                    {
                                                                        "Literal": {
                                                                            "Value": "null"
                                                                        }
                                                                    }
                                                                ]
                                                            ],
                                                        }
                                                    }
                                                }
                                            }
                                        },
                                    ],
                                }
                            ],
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "73a64094acbd371ddd40",
                }
            ],
        },
    }
]

_manufacturer_supplied_used_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "c1", "Entity": "Calendar", "Type": 0},
                                {"Name": "c", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "n", "Entity": "xls_NIJZ_Odmerki", "Type": 0},
                                {"Name": "s", "Entity": "Sifrant_Cepivo", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "c1"}},
                                        "Property": "Date",
                                    },
                                    "Name": "Calendar.Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Kumulativno skupaj cepljenih",
                                    },
                                    "Name": "eRCO_podatki.Kumulativno skupaj cepljenih",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "n"}},
                                        "Property": "Tekoča vsota za mero odmerki*​ v polju Date",
                                    },
                                    "Name": "NIJZ_Odmerki.Tekoča vsota za mero odmerki* v polju Date",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 2,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c1"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "s"}
                                                        },
                                                        "Property": "Cepivo_Ime",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [
                                                    {
                                                        "Literal": {
                                                            "Value": "'Pfizer-BioNTech'"
                                                        }
                                                    }
                                                ]
                                            ],
                                        }
                                    }
                                },
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0, 1, 2]}]},
                            "DataReduction": {
                                "DataVolume": 4,
                                "Primary": {"BinnedLineSample": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "8233796ced1be0a31515",
                }
            ],
        },
    }
]

male_dose_1_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {
                                    "Name": "e",
                                    "Entity": "eRCO_\u200b\u200bpodatki",
                                    "Type": 0,
                                },
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Weight for 1",
                                    },
                                    "Name": "eRCO_podatki.Weight for 1",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Moški'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 3,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "Literal": {
                                                    "Value": "datetime'2021-05-03T00:00:00'"
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Measure": {
                                            "Expression": {
                                                "SourceRef": {"Source": "e"}
                                            },
                                            "Property": "Weight for 1",
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "8233796ced1be0a31515",
                }
            ],
        },
    }
]

male_dose_2_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {
                                    "Name": "e",
                                    "Entity": "eRCO_\u200b\u200bpodatki",
                                    "Type": 0,
                                },
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "Precepljenost",
                                            }
                                        },
                                        "Function": 0,
                                    },
                                    "Name": "Sum(eRCO_podatki_ed.Precepljenost)",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Moški'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 3,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "Literal": {
                                                    "Value": "datetime'2021-05-03T00:00:00'"
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Aggregation": {
                                            "Expression": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "e"}
                                                    },
                                                    "Property": "Precepljenost",
                                                }
                                            },
                                            "Function": 0,
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "8233796ced1be0a31515",
                }
            ],
        },
    }
]

group_date_range_queries = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "c", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c1", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "c1"}},
                                        "Property": "Date",
                                    },
                                    "Name": "Calendar.Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Weight running total in Date",
                                    },
                                    "Name": "eRCO_podatki.Weight running total in Date",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "c"}},
                                        "Property": "Tekoča vsota za mero Precepljenost v polju Date",
                                    },
                                    "Name": "eRCO_podatki_ed.Tekoča vsota za mero Precepljenost v polju Date",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c1"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c1"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c1"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0, 1, 2]}]},
                            "DataReduction": {
                                "DataVolume": 4,
                                "Primary": {"BinnedLineSample": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "37907fcc1d650bd01406",
                }
            ],
        },
    }
]

male1_date_range_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Weight for 1",
                                    },
                                    "Name": "eRCO_podatki.Weight for 1",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Moški'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Measure": {
                                            "Expression": {
                                                "SourceRef": {"Source": "e"}
                                            },
                                            "Property": "Weight for 1",
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "37907fcc1d650bd01406",
                }
            ],
        },
    }
]

male2_date_range_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "Precepljenost",
                                            }
                                        },
                                        "Function": 0,
                                    },
                                    "Name": "Sum(eRCO_podatki_ed.Precepljenost)",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Moški'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Aggregation": {
                                            "Expression": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "e"}
                                                    },
                                                    "Property": "Precepljenost",
                                                }
                                            },
                                            "Function": 0,
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "58905942ae8d24176dbd",
                }
            ],
        },
    }
]

female1_date_range_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Weight for 1",
                                    },
                                    "Name": "eRCO_podatki.Weight for 1",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Ženske'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Measure": {
                                            "Expression": {
                                                "SourceRef": {"Source": "e"}
                                            },
                                            "Property": "Weight for 1",
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "df157d8c2c7b603db9b4",
                }
            ],
        },
    }
]

female2_date_range_queries_2021_05_01_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Aggregation": {
                                        "Expression": {
                                            "Column": {
                                                "Expression": {
                                                    "SourceRef": {"Source": "e"}
                                                },
                                                "Property": "Precepljenost",
                                            }
                                        },
                                        "Function": 0,
                                    },
                                    "Name": "Sum(eRCO_podatki_ed.Precepljenost)",
                                }
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "In": {
                                            "Expressions": [
                                                {
                                                    "Column": {
                                                        "Expression": {
                                                            "SourceRef": {"Source": "e"}
                                                        },
                                                        "Property": "OsebaSpol",
                                                    }
                                                }
                                            ],
                                            "Values": [
                                                [{"Literal": {"Value": "'Ženske'"}}]
                                            ],
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Aggregation": {
                                            "Expression": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "e"}
                                                    },
                                                    "Property": "Precepljenost",
                                                }
                                            },
                                            "Function": 0,
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "00a1a6bd176268d0daab",
                }
            ],
        },
    }
]

manufacturers_date_range_queries_2021_05_21_2021_05_03 = [
    {
        "Query": {
            "Commands": [
                {
                    "SemanticQueryDataShapeCommand": {
                        "Query": {
                            "Version": 2,
                            "From": [
                                {"Name": "e", "Entity": "eRCO_​​podatki", "Type": 0},
                                {"Name": "s", "Entity": "Sifrant_Cepivo", "Type": 0},
                                {"Name": "c", "Entity": "Calendar", "Type": 0},
                            ],
                            "Select": [
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Weight for 1",
                                    },
                                    "Name": "eRCO_podatki.Weight for 1",
                                },
                                {
                                    "Measure": {
                                        "Expression": {"SourceRef": {"Source": "e"}},
                                        "Property": "Weight for 2",
                                    },
                                    "Name": "eRCO_podatki.Weight for 2",
                                },
                                {
                                    "Column": {
                                        "Expression": {"SourceRef": {"Source": "s"}},
                                        "Property": "Cepivo_Ime",
                                    },
                                    "Name": "Sifrant_Cepivo.Cepivo_Ime",
                                },
                            ],
                            "Where": [
                                {
                                    "Condition": {
                                        "Not": {
                                            "Expression": {
                                                "In": {
                                                    "Expressions": [
                                                        {
                                                            "Column": {
                                                                "Expression": {
                                                                    "SourceRef": {
                                                                        "Source": "s"
                                                                    }
                                                                },
                                                                "Property": "Cepivo_Ime",
                                                            }
                                                        }
                                                    ],
                                                    "Values": [
                                                        [{"Literal": {"Value": "null"}}]
                                                    ],
                                                }
                                            }
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "And": {
                                            "Left": {
                                                "Comparison": {
                                                    "ComparisonKind": 2,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-01T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                            "Right": {
                                                "Comparison": {
                                                    "ComparisonKind": 3,
                                                    "Left": {
                                                        "Column": {
                                                            "Expression": {
                                                                "SourceRef": {
                                                                    "Source": "c"
                                                                }
                                                            },
                                                            "Property": "Date",
                                                        }
                                                    },
                                                    "Right": {
                                                        "Literal": {
                                                            "Value": "datetime'2021-05-03T00:00:00'"
                                                        }
                                                    },
                                                }
                                            },
                                        }
                                    }
                                },
                                {
                                    "Condition": {
                                        "Comparison": {
                                            "ComparisonKind": 1,
                                            "Left": {
                                                "Column": {
                                                    "Expression": {
                                                        "SourceRef": {"Source": "c"}
                                                    },
                                                    "Property": "Date",
                                                }
                                            },
                                            "Right": {
                                                "DateSpan": {
                                                    "Expression": {
                                                        "Literal": {
                                                            "Value": "datetime'2020-12-26T00:00:00'"
                                                        }
                                                    },
                                                    "TimeUnit": 5,
                                                }
                                            },
                                        }
                                    }
                                },
                            ],
                            "OrderBy": [
                                {
                                    "Direction": 2,
                                    "Expression": {
                                        "Measure": {
                                            "Expression": {
                                                "SourceRef": {"Source": "e"}
                                            },
                                            "Property": "Weight for 2",
                                        }
                                    },
                                }
                            ],
                        },
                        "Binding": {
                            "Primary": {"Groupings": [{"Projections": [0, 1, 2]}]},
                            "DataReduction": {
                                "DataVolume": 3,
                                "Primary": {"Window": {}},
                            },
                            "Version": 1,
                        },
                        "ExecutionMetricsKind": 1,
                    }
                }
            ]
        },
        "QueryId": "",
        "ApplicationContext": {
            "DatasetId": "51c64860-e9ec-49d8-8a36-743bced78e1a",
            "Sources": [
                {
                    "ReportId": "dddc4907-41d2-4b6c-b34b-3aac90b7fdee",
                    "VisualId": "61ce741d0886b757de37",
                }
            ],
        },
    }
]


@skip
class CepimoseTestCommands(unittest.TestCase):
    def setUp(self):
        super().setUp()
        self.maxDiff = None

    def tearDown(self):
        super().tearDown()

    def get_command(self, obj: "list[dict]"):
        print(obj)
        return obj[0]["Query"]["Commands"][0]

    def get_SemanticQueryDataShapeCommand_field(
        self, obj: "list[dict]", field: str = "Query"
    ):
        command = self.get_command(obj)
        return command["SemanticQueryDataShapeCommand"].get(field, None)

    def compare(self, real: dict, our: dict):
        for key, value in real.items():
            print(key, value)
            print(key, our[key])
            print()
            if isinstance(value, dict):
                self.assertDictEqual(
                    value,
                    our[key],
                )
            else:
                self.assertEqual(
                    value,
                    our[key],
                )

    # @unittest.skip("TODO")
    def test_timestamp_command(self):
        ts_command = self.get_command(_timestamp_queries)
        self.assertDictEqual(
            ts_command,
            cepimose.data._vaccinations_timestamp_command,
        )

    # @unittest.skip("TODO")
    def test_by_age_group_command(self):
        age_group_commands = cepimose.data._create_by_age_group_commands()
        group_90_command = age_group_commands[AgeGroup.GROUP_90][0]
        self.assertDictEqual(self.get_command(_by_age_group_queries), group_90_command)

    # @unittest.skip("TODO")
    def test_by_region_by_day_command(self):
        region_commands = cepimose.data._create_by_region_by_day_commands()
        region_pomurska_command = region_commands[Region.POMURSKA][0]
        self.assertDictEqual(
            self.get_command(_by_region_by_day_queries), region_pomurska_command
        )

    # @unittest.skip("TODO")
    def test_age_group_by_region_command(self):
        age_group_commands = cepimose.data._create_age_group_by_region_on_day_commands()
        group_90_command = age_group_commands[AgeGroup.GROUP_90][0]
        self.assertDictEqual(
            self.get_command(_age_group_by_region_queries), group_90_command
        )

    # @unittest.skip("TODO")
    def test_age_group_by_region_command(self):
        manufacturer_commands = (
            cepimose.data._create_vaccination_by_manufacturer_supplied_used_commands()
        )
        pfizer_command = manufacturer_commands[Manufacturer.PFIZER][0]
        self.assertDictEqual(
            self.get_command(_manufacturer_supplied_used_queries), pfizer_command
        )

    # @unittest.skip("TODO")
    def test_gender_commands(self):
        gender_commands = cepimose.data._create_vaccinations_gender_commands(
            start_date=datetime.datetime(2021, 5, 1),
            end_date=datetime.datetime(2021, 5, 3),
        )
        male_commands = gender_commands[Gender.MALE]
        male_dose_1_command, male_dose_2_command = male_commands
        self.assertDictEqual(
            self.get_command(male_dose_1_queries_2021_05_01_2021_05_03),
            male_dose_1_command,
        )
        self.assertDictEqual(
            self.get_command(male_dose_2_queries_2021_05_01_2021_05_03),
            male_dose_2_command,
        )

    # @unittest.skip("TODO")
    def test_date_range_commands(self):
        date_range_commands = cepimose.commands._get_date_range_group_commands(
            start_date=datetime.datetime(2021, 5, 1),
            end_date=datetime.datetime(2021, 5, 3),
            group=None,
        )

        self.assertDictEqual(
            self.get_command(group_date_range_queries), date_range_commands.group
        )

        real_male_1_Query = self.get_command(
            male1_date_range_queries_2021_05_01_2021_05_03
        )
        real_male_2_Query = self.get_command(
            male2_date_range_queries_2021_05_01_2021_05_03
        )
        real_female_1_Query = self.get_command(
            female1_date_range_queries_2021_05_01_2021_05_03
        )
        real_female_2_Query = self.get_command(
            female2_date_range_queries_2021_05_01_2021_05_03
        )
        real_manufacturers_Query = self.get_command(
            manufacturers_date_range_queries_2021_05_21_2021_05_03
        )

        self.assertDictEqual(real_male_1_Query, date_range_commands.male1)
        self.assertDictEqual(real_male_2_Query, date_range_commands.male2)
        self.assertDictEqual(real_female_1_Query, date_range_commands.female1)
        self.assertDictEqual(real_female_2_Query, date_range_commands.female2)
        self.assertDictEqual(
            real_manufacturers_Query, date_range_commands.manufacturers
        )
